#!/bin/bash
#
# author           : P.R. Faasse (p.faase1@chello.nl)
# maintainer       : P.R. Faasse
# latest update    : 21-feb-2008
# status           : testing
# update history: 
# 2.2.1/52.2: ownership of the /usr/share/gambas2 directory files made root:root
# 2.3.0/52.3: added a 48x48 icon + updated the slack-desc (we're safely past version 2 now..
# 2.7.0/54.1: rebuild for new gambas version				
# 2.8.0/54.1: rebuild for new version

#
# what package is going to be built
#
softname='gambas2'
softversion='2.8.2'
#
# The traditional 'lonesome' hook: used to create a full build-log; see the end of 
# the buildfile for the other end of the hook
#
(
#
# where could you get the source
#

srcurl="http://surfnet.dl.sourceforge.net/sourceforge/gambas/$softname-$softversion.tar.bz2"
#
# ZenWalk standard: CPU type and architecture, as well as the
# version number of ZenWalk this package is made for (on?).
#
# arch='i486' -> the compiler uses only 80486 instructions
# cpu='i686'  -> the optimising is done for a PII and above CPU
# packageversion='46.1' means: 
# 46 -> ZenWalk-4.6 
# .  -> separator
# 1  -> build #1 for this ZenWalk version  
#
arch='i486'
cpu='i686'
packageversion='54.1'
#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'
#
# parameters needed for the build process
#
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#

echo "-- build-time dependencies check -----"

depsok=passed

cd /var/log/packages
 
#
# build-time dependencies check
#
for file in \
  qt-base \
  libmikmod \
  mysql \
  sqlite \
  postgresql \
  libffi \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file-?.* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi
   #
done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi
#
echo "-- source archive check -----"

if [ -r "$softname-$softversion.tar.bz2" ]; then 
  echo "Usable source archive: $softname-$softversion.tar.bz2 found: good ...";
else 
  echo "No source archive: $softname-$softversion.tar.bz2 found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl"
  echo
  exit 1;
fi
#
# prepare the build result directory
#
dest="$buildir/$package"
prefix=/usr
#
rm -rf $dest
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
#
# These two are always needed: 
# applications for the $softname.desktop file, 
# icons for the application icon $softname.png
#
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons
mkdir -p $dest/usr/doc
#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc
#
# make a slack-desc file
#
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
$softname: An integrated oo-basic environment
$softname:
$softname: Gambas Almost Means BASic: an advanced integrated development 
$softname: environment for the BASIC language.
$softname: 
$softname: see also: http://gambas.sourceforge.net/
$softname: 
$softname:
$softname: 
$softname:
$softname: 
EOF
#
# generate the desktop file, see below for the icon files
#
cat <<"EOF" >$dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Gambas2
Comment=Integrated Basic Development Environment
Exec=gambas2
Icon=gambas2
Terminal=false
X-MultipleArgs=false
Type=Application
Categories=Application;Development;
Encoding=UTF-8
StartupNotify=true
EOF
#
# extrac the source archive
#
cd $buildir
file="$softname-$softversion.tar.bz2"
srcdir="$(basename $file .tar.bz2)"
#
echo "-- removing old build-directory -----"

rm -rf $srcdir
#
echo "-- extracting the source archive -----"

tar jxvf $file
cd $srcdir
#
# make the package-dependent directories
#
mkdir -p $dest/usr/doc/$srcdir
#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
#
# configure package for compilation
#
echo "-- configure -----"

#
# Note: i disabled pdf: it results in a compile error in version 1.9.49
# Note: i re-enabled it in 1.9.51; seems to work ok again...
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"  
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"  
./configure \
   --prefix=$prefix \
   --mandir=/usr/man \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --disable-debug \
   --program-prefix="" \
   --program-suffix="" \
   || exit 1

# --with-ffi-includes=/usr/lib/libffi-3.0.1/include \
#
# make package
#
echo "-- make -----"

make $numjobs \
   || exit 1
#
# install package to the target directory
#
echo "-- make install -----"

make install DESTDIR=$dest \
   || exit 1
#
# add 'default' files
#
echo "-- adding default files -----"

cp -a \
   AUTHORS COPYING INSTALL NEWS README TODO \
   $dest/usr/doc/$srcdir 
#
# copy the icon files from the gambas source tree
#
mkdir -p $dest/usr/share/icons/hicolor/16x16/apps
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
#
cp app/src/$softname/img/logo/new-logo-16.png $dest/usr/share/icons/hicolor/16x16/apps/$softname.png
cp app/src/$softname/img/logo/new-logo-32.png $dest/usr/share/icons/hicolor/32x32/apps/$softname.png
cp app/src/$softname/img/logo/new-logo.png $dest/usr/share/icons/hicolor/128x128/apps/$softname.png
#
# my own gimping... 
#
cp $buildir/logo-48.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png
#
# <disabled> until further notice... 
#
# I tried this, but it messed up the existing mime-types, and did not
# work for gambas executables. There may well be a way to do this right,
# but i've not yet found it
#
##
## integrate gambas into kde, recipe 'stolen' from:
## http://gambasdoc.org/help/howto/autorun
##
#mkdir     -p $dest/usr/share/mimelnk/application
#cat <<"EOF" >$dest/usr/share/mimelnk/application/x-gambas.desktop
#[Desktop Entry]
#Encoding=UTF-8
#Comment=Gambas executable
#Icon=binary
#Type=MimeType
#MimeType=application/x-gambas
#EOF
##
#mkdir -p     $dest/usr/share/applnk/.hidden
#cat <<"EOF" >$dest/usr/share/applnk/.hidden/gbr2.desktop
#[Desktop Entry]
#Exec=gbr2
#InitialPreference=1
#MimeType=application/x-gambas
#Name=gbr2
#Terminal=false
#Type=Application
#EOF
##
## My 'touch': add the gambas type to the list of known mime-types
##
## triksy: we have to add this line 
##
##0      string     #!/usr/bin/gbr2    application/x-gambas
##
## to the file:
##
## usr/share/mimelnk/magic, on the target system....
##
## That is a job for doinst.sh, but we want to see that line only
## once... If someone installs gambas n times, we do not want n of these
## lines popping up all over the mime-types file... I have done this
## before, the old-style mechanism of ld.so.conf was the same as this...
##
## One trouble: this does not get removed when the gambas2 package is
## un-installed... It does no real harm as far as i can tell, but
## removing the entry upon de-installation would have been nicer...
##
## oh, and by all means avoid absolute paths in the doinst script...
## implicit assumption is that the doinst is run from the 'root'
## directory. 
##
#cat <<"EOF" >>$dest/install/doinst.sh
##
## adding the gambas magic line to /usr/share/mimelnk/magic
##
#ff=`grep "application/x-gambas" usr/share/mimelnk/magic`
###
#if [ ! "$ff" ]; then
#	#
#	echo "adding the gambas2 magic entry to the file: /usr/share/mimelnk/magic"
#	#
#	echo "#"                                                         >>usr/share/mimelnk/magic
#	echo "# the magic line for gambas2 applications"                 >>usr/share/mimelnk/magic
#	echo "#"                                                         >>usr/share/mimelnk/magic
#	echo "0      string     #!/usr/bin/gbr2    application/x-gambas" >>usr/share/mimelnk/magic
#	#
#fi
##
## remove the temp-var
##
#unset ff
#EOF
#
# </disabled>
#

#
# while we're at it: add the gambas shared libs
# (/usr/lib/gambas2) to the ld.so.conf
#
mkdir -p                 $dest/etc/ld.so.conf.d
echo "/usr/lib/gambas2" >$dest/etc/ld.so.conf.d/gambas2.conf
# 
# as per package rules: add the build-file itself
#
echo "-- adding package-rules files -----"

cp "$buildir/build-$softname.sh" \
   "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"
#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF
chmod a+x "$destsrc/getsrc.sh"
#
# my logo... scaled down from 128x128
#
cp $buildir/logo-48.png $destsrc/logo-48.png
#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
echo "-- pre-packaging configuration -----"

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)
#
# set files permissions
#
chown -R root.root $dest/usr/bin
chown -R root.root $dest/$prefix/share/gambas2
#
# real packaging work: 
#
echo "-- packaging -----"

cd $dest
makepkg -p -l y -c n $dest.tgz
#
# this makes that the md5 file does not contain the complete path of the package-build....
#
(
 cd $buildir
 #
 echo "-- generating the md5/src file -----"
 md5sum $package.tgz >$package.md5
 echo $srcurl >$package.src
 #
 echo "-- generating the dep file -----"
 EXCLUDE=mysql,sqlite,postgresql requiredbuilder -z $package.tgz >$package.dep
 #
)
#
# the other end of the lonesome hook: here we create the build-log
#
) 2>&1 | tee "$softname-$softversion-info.txt"
